""" Distutils script. Use 'python setup.py install' to install pxtl package.
"""

import os, string
from distutils.core import setup
from distutils.command.build_py import build_py

# The pxtl package requires the system template '__error__.px' to be included
# in its package directory. Normally distutils does not allow non-module files
# to be included in a package directory, so override the build_py command to
# copy .px files as well as .py files to the build directory.
#
class build_px(build_py):
  def build_packages(self):
    build_py.build_packages(self)
    for package in self.packages:
      package_dir= self.get_package_dir(package)
      for template in os.listdir(package_dir):
        if template[-3:]=='.px':
          infile= os.path.join(package_dir, template)
          outpath= [self.build_lib]+string.split(package, '.')+[template]
          self.copy_file(infile,apply(os.path.join, outpath),preserve_mode=0)

# Invoke distutils, using overridden build_py.
#
setup(
  name= 'pxtl',
  version= '1.0',
  description= 'Python XML Templating Language implementation',
  author= 'Andrew Clover',
  author_email= 'and@doxdesk.com',
  url= 'http://www.doxdesk.com/software/py/pxtl.html',
  packages= ['pxtl'],
  cmdclass= {'build_py': build_px}
)
